@@ -10,7 +10,7 @@ _LOGGER = logging.getLogger(__name__)
 class Map:
     def __init__(self):
         self.buffer = np.zeros((64, 100, 100))
-        self.mapPieces = np.empty((64), str)
+        self.mapPieces = np.empty((64), np.dtype('U100'))
         self.isMapUpdated = False
         self.base64Image = None
 
@@ -24,7 +24,6 @@ class Map:
 
             self.isMapUpdated = False
 
-            _LOGGER.debug("AddMapPiece to update")
             if str(mapPiece) != '1295764014':
                 return True
             else:
@@ -98,61 +97,16 @@ class Map:
             im = ImageOps.flip(im)
             _LOGGER.debug("GetBase64Map finish flip")
             
+            #Crop
+            imageBox = im.getbbox()
+            cropped=im.crop(imageBox)
+            _LOGGER.debug("GetBase64Map finish crop")
+            #save
             buffered = BytesIO()
-            _LOGGER.debug("buffered = BytesIO()")
-            im.save(buffered, format="PNG")
-            _LOGGER.debug("im.save(buffered, format=PNG)")
+            cropped.save(buffered, format="PNG")
+            _LOGGER.debug("GetBase64Map finish saving")
             self.isMapUpdated = True
 
-            base64Image = base64.b64encode(buffered.getvalue())
-            _LOGGER.debug("base64Image = base64.b64encode(buffered.getvalue())")
-            
-            #Crop
-            #image_data = np.asarray(im)
-            #_LOGGER.debug("image_data = np.asarray(im)")
-            #del im
-            #_LOGGER.debug("del im")
+            self.base64Image = base64.b64encode(buffered.getvalue())
 
-            #image_data_bw = image_data.max(axis=2)
-            #_LOGGER.debug("image_data_bw = image_data.max(axis=2)")
-
-            #non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]
-            #_LOGGER.debug("non_empty_columns = np.where(image_data_bw.max(axis=0)>0)[0]")
-
-            #non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]
-            #_LOGGER.debug("non_empty_rows = np.where(image_data_bw.max(axis=1)>0)[0]")
-
-            #cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))
-            #_LOGGER.debug("cropBox = (min(non_empty_rows), max(non_empty_rows), min(non_empty_columns), max(non_empty_columns))")
-
-            #image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]
-            #_LOGGER.debug("image_data_new = image_data[cropBox[0]:cropBox[1]+1, cropBox[2]:cropBox[3]+1 , :]")
-
-            #del image_data
-            #_LOGGER.debug("del image_data")
-
-            #new_image = Image.fromarray(image_data_new)
-            #_LOGGER.debug("new_image = Image.fromarray(image_data_new)")
-
-            #del image_data_new
-            #_LOGGER.debug("del image_data_new")
-
-            #buffered = BytesIO()
-            #_LOGGER.debug("buffered = BytesIO()")
-
-            #_LOGGER.debug("GetBase64Map finish crop")
-
-            #new_image.save(buffered, format="PNG")
-            #_LOGGER.debug("new_image.save(buffered, format=PNG)")
-
-            #del new_image
-            #_LOGGER.debug("del new_image")
-
-            #_LOGGER.debug("GetBase64Map finish saving")
-
-            #self.isMapUpdated = True
-
-            #base64Image = base64.b64encode(buffered.getvalue())
-
-            #_LOGGER.debug("GetBase64Map done")
-        return base64Image
\ No newline at end of file
+        return self.base64Image
\ No newline at end of file
